==> Tagz-1.0.0.zip: Tagz/lang/ro.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Cuvinte cheie',
 'L_TITLE'=>'Modificați cuvintele cheie pentru site',
 'L_DESCRIPTION'=>'Gestionați etichetele site-ului. Ștergeți sau redenumiți setul de cuvinte cheie.',
#admin
 'L_CANCEL'=>'Anulează toate',
 'L_DEVIENT'=>'devine',
 'L_POUR'=>'pentru',
 'L_SEARCH'=>'Căutați în articole cu acest cuvânt cheie',
 'L_RESTORE'=>'restabili',
 'L_DEL'=>'pune în umbră',
 'L_RESTORE_ALL'=>'Restabiliți toate câmpurile rămase goale',
 'L_DEL_ALL'=>'Ștergeți toate câmpurile',
 'L_ART_NUM'=>'Pentru articolul (ele) cu numărul (numerele)',
 'L_HELP_TAG_FIELD'=>'Dacă câmpul este gol, aceasta șterge cuvântul cheie după salvare.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'reîmprospăta',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Fișier Tags.xml actualizat de cuvintele cheie ale articolelor',
 'L_TAG_PLACEHOLDER'=>'Șterse dacă sunt lăsate goale',
 'L_DEDUPLICATED'=>'deduplicat',
 'L_IN_REALITY'=>'În realitate',
 'L_IS_UNIK'=>'Unic (este solo)',
 'L_DOUBLES'=>'dublu',
 'L_TRIPLES'=>'triplete',
 'L_QUADRUPLES'=>'cvadruplu',
 'L_QUINTUPLES'=>'cvintuplu',
 'L_SEXTUPLES'=>'sextuple',
 'L_SEPTUPLES'=>'de șapte ori atât',
#config
 'L_ACCES'=>'Tip (e) de cont (e) * autorizat să acceseze pluginul',
 'L_HELP_ACCES'=>'La care profiluri * este permis să utilizeze pluginul. Se afișează separat prin virgule (implicit PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Utilizator (i) interzis accesării pluginului (meniul ascuns)',
 'L_HELP_DENY'=>'Care sunt identificatorii utilizatorilor cărora li se interzice utilizarea pluginului. Lista separată de liste (De exemplu, 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/ro.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Cuvinte cheie',
 'L_TITLE'=>'Modificați cuvintele cheie pentru site',
 'L_DESCRIPTION'=>'Gestionați etichetele site-ului. Ștergeți sau redenumiți setul de cuvinte cheie.',
 'L_FILTER_TAGS'=>'Filtrarea cuvintele cheie',
 'L_FILTER_TAGS_PH'=>'Filtru de cuvinte',
 'L_CANCEL'=>'Anulează toate',
 'L_DEVIENT'=>'devine',
 'L_POUR'=>'pentru',
 'L_SEARCH'=>'Căutați în articole cu acest cuvânt cheie',
 'L_RESTORE'=>'restabili',
 'L_DEL'=>'pune în umbră',
 'L_RESTORE_ALL'=>'Restabiliți toate câmpurile rămase goale',
 'L_DEL_ALL'=>'Ștergeți toate câmpurile',
 'L_ART_NUM'=>'Pentru articolul (ele) cu numărul (numerele)',
 'L_HELP_TAG_FIELD'=>'Dacă câmpul este gol, aceasta șterge cuvântul cheie după salvare.',
 'L_HELP_TAG_CTRLZ'=>'Combinația de taste Ctrl-z vă permite să anulați',
 'L_TAGS_REFRESH'=>'reîmprospăta',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Fișier Tags.xml actualizat de cuvintele cheie ale articolelor',
 'L_TAG_PLACEHOLDER'=>'Șterse dacă sunt lăsate goale',
 'L_DEDUPLICATED'=>'deduplicat',
 'L_IN_REALITY'=>'În realitate',
 'L_IS_UNIK'=>'Unic (este solo)',
 'L_DOUBLES'=>'dublu',
 'L_TRIPLES'=>'triplete',
 'L_QUADRUPLES'=>'cvadruplu',
 'L_QUINTUPLES'=>'cvintuplu',
 'L_SEXTUPLES'=>'sextuple',
 'L_SEPTUPLES'=>'de șapte ori atât',
 'L_OCTUPLES'=>'Octuples (În sără- șlem)',
 'L_NONUPLES'=>'Nonuples (Nonuples)',
 'L_DECUPLES'=>'De zece ori',
#config
 'L_ACCES'=>'Tip (e) de cont (e) * autorizat să acceseze pluginul',
 'L_HELP_ACCES'=>'La care profiluri * este permis să utilizeze pluginul. Se afișează separat prin virgule (implicit PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Utilizator (i) interzis accesării pluginului (meniul ascuns)',
 'L_HELP_DENY'=>'Care sunt identificatorii utilizatorilor cărora li se interzice utilizarea pluginului. Lista separată de liste (De exemplu, 001,002,007).',
);
?>
